@@ -1,7 +1,7 @@
 /* This file is part of the KDE libraries
    SPDX-FileCopyrightText: 2009 Dario Freddi <drf at kde.org>
 
-   SPDX-License-Identifier: LGPL-2.0-only
+   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 // Exceptionnally, include QCoreApplication before our own header, because that one includes X11 headers (#define None...)
@@ -12,7 +12,12 @@
 #include "xsyncbasedpoller.h"
 
 #include <QAbstractNativeEventFilter>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QGuiApplication>
+#else
 #include <QX11Info>
+#endif
+
 #include <X11/Xlib-xcb.h> // XGetXCBConnection
 #include <xcb/sync.h>
 
@@ -24,7 +29,7 @@ public:
         , isActive(false)
     {
     }
-    ~XSyncBasedPollerHelper()
+    ~XSyncBasedPollerHelper() override
     {
         delete q;
     }
@@ -57,8 +62,13 @@ XSyncBasedPoller *XSyncBasedPoller::instance()
 
 XSyncBasedPoller::XSyncBasedPoller(QObject *parent)
     : AbstractSystemPoller(parent)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    , m_display(qGuiApp->nativeInterface<QNativeInterface::QX11Application>()->display())
+#else
     , m_display(QX11Info::display())
+#endif
     , m_xcb_connection(nullptr)
+    , m_sync_event(0)
     , m_idleCounter(None)
     , m_resetAlarm(None)
     , m_available(true)
@@ -336,3 +346,5 @@ void XSyncBasedPoller::simulateUserActivity()
     XResetScreenSaver(m_display);
     XFlush(m_display);
 }
+
+#include "moc_xsyncbasedpoller.cpp"
