@@ -1,7 +1,7 @@
 /* This file is part of the KDE libraries
  * SPDX-FileCopyrightText: 2009 Dario Freddi <drf at kde.org>
  *
- * SPDX-License-Identifier: LGPL-2.0-only
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef WIDGETBASEDPOLLER_H
@@ -13,6 +13,7 @@
 
 class QTimer;
 class QEvent;
+class QWindow;
 
 class KIDLETIME_EXPORT WidgetBasedPoller : public AbstractSystemPoller
 {
@@ -26,13 +27,15 @@ public:
     bool setUpPoller() override;
     void unloadPoller() override;
 
+    QList<int> timeouts() const override;
+
 protected:
     bool eventFilter(QObject *object, QEvent *event) override;
 
 public Q_SLOTS:
     void addTimeout(int nextTimeout) override;
     void removeTimeout(int nextTimeout) override;
-    QList<int> timeouts() const override;
+
     int forcePollRequest() override;
     void catchIdleEvent() override;
     void stopCatchingIdleEvents() override;
@@ -49,7 +52,7 @@ private:
 
 private:
     QTimer *m_pollTimer;
-    QWidget *m_grabber;
+    QWindow *m_grabber;
     QList<int> m_timeouts;
 };
 
